django\_sorcery.management.commands.sorcery\_upgrade module
===========================================================

.. automodule:: django_sorcery.management.commands.sorcery_upgrade
   :members:
   :undoc-members:
   :show-inheritance:
